@@ -37,7 +37,7 @@
 #include "plugin.h"
 #include "obex.h"
 #include "service.h"
-#include "logging.h"
+#include "log.h"
 #include "dbus.h"
 
 #define VCARD_TYPE "text/x-vcard"
@@ -82,7 +82,6 @@
 								\
   <attribute id=\"0x0303\">					\
     <sequence>							\
-      <uint8 value=\"0x01\"/>					\
       <uint8 value=\"0x01\"/>					\
       <uint8 value=\"0x02\"/>					\
       <uint8 value=\"0x03\"/>					\
@@ -156,7 +155,8 @@ skip_auth:
 	return ret;
 }
 
-static int opp_put(struct obex_session *os, void *user_data)
+static int opp_put(struct obex_session *os, obex_object_t *obj,
+						void *user_data)
 {
 	const char *name = obex_get_name(os);
 	const char *folder = obex_get_root_folder(os);
